@@ -20,7 +20,9 @@ pymysql.install_as_MySQLdb()
 
 class ForApp():
     def __init__(self, import_name, MONGO_HOST_URL, secret_key, log_folder=None, root_path=None,
-                 need_before_request=True):
+                 need_before_request=True,
+                 need_after_request=True,
+                 ):
         self.import_name = import_name
         self.log_folder = log_folder
 
@@ -88,41 +90,41 @@ class ForApp():
                     pass
                 g.ip = ip
                 g.error = False
+        if need_after_request:
+            @app.after_request
+            def after_request(response):
+                foot = Foot()
+                # 访问用户ID
+                user_id = session.get('user_id', None)
+                if user_id:
+                    foot.user_id = ObjectId(user_id)
+                # 请求url
+                foot.url = request.url
+                # 请求原网址
+                foot.referrer = request.referrer
+                # IP
+                foot.ip = g.ip
 
-        @app.after_request
-        def after_request(response):
-            foot = Foot()
-            # 访问用户ID
-            user_id = session.get('user_id', None)
-            if user_id:
-                foot.user_id = ObjectId(user_id)
-            # 请求url
-            foot.url = request.url
-            # 请求原网址
-            foot.referrer = request.referrer
-            # IP
-            foot.ip = g.ip
+                # 请求开始时间：
+                foot.request_start_time = g.request_start_time
+                # 请求结束时间：
+                foot.request_end_time = datetime.datetime.now()
+                foot.cookies = request.cookies
+                ForLog.show("请求的cookies", request.cookies)
+                ForLog.show("请求的cookies type", type(request.cookies))
+                headers_before = request.headers
+                if headers_before:
+                    headers = {}
+                    for key, value in headers_before.to_wsgi_list():
+                        headers[key] = value
+                    foot.headers = headers
 
-            # 请求开始时间：
-            foot.request_start_time = g.request_start_time
-            # 请求结束时间：
-            foot.request_end_time = datetime.datetime.now()
-            foot.cookies = request.cookies
-            ForLog.show("请求的cookies", request.cookies)
-            ForLog.show("请求的cookies type", type(request.cookies))
-            headers_before = request.headers
-            if headers_before:
-                headers = {}
-                for key, value in headers_before.to_wsgi_list():
-                    headers[key] = value
-                foot.headers = headers
-
-            # 请求方式
-            foot.method = request.method
-            # 错误异常
-            foot.error = str(g.error) if g.error else None
-            foot.save()
-            return response
+                # 请求方式
+                foot.method = request.method
+                # 错误异常
+                foot.error = str(g.error) if g.error else None
+                foot.save()
+                return response
 
         @app.teardown_request
         def teardown_request(error):
